<?php
/**
 * Webkul MarketingCloud Magento Connector SyncCustomer Controller
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */
namespace Webkul\MarketingCloudMagentoConnector\Controller\Adminhtml\Customer;

use Magento\Backend\App\Action;
use Magento\Ui\Component\MassAction\Filter;
use Magento\Framework\Controller\ResultFactory;
use Magento\Customer\Model\ResourceModel\Customer\CollectionFactory;

class SyncCustomer extends \Magento\Backend\App\Action
{
    /**
     * @param Action\Context $context
     * @param Filter $filter
     * @param CollectionFactory $collectionFactory
     */
    protected $_collectionFactory;
    protected $_filter;

    public function __construct(
        Filter $filter,
        CollectionFactory $collectionFactory,
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection
    ) {
        parent::__construct($context);
        $this->_filter = $filter;
        $this->_connection = $connection;
        $this->_scopeConfig = $scopeConfig;
        $this->_messageManager = $messageManager;
        $this->_collectionFactory = $collectionFactory;
    }

    public function execute()
    {
        $helper = $this->_connection;
        $sessionToken = $this->_session->getMarketingToken();
        $token = $this->_scopeConfig->getValue('marketingcloud/general/mc_conn_token');
        $relToken = $helper->genarateToken();
        if (isset($token) && $token != null) {
            $sessionToken = $token;
        }
        if ($sessionToken != $relToken) {
            $resultRedirect = $this->resultRedirectFactory->create();
            $this->messageManager->addError(__("Licence Invalid, Kindly use correct licence key!!!"));
            return $resultRedirect->setPath('adminhtml/system_config/edit/section/marketingcloudmagentoconnector');
        }
        $storeId = (int) $this->getRequest()->getParam('store', 0);
        $helper = $this->_connection;
        $helper->callMcMethod();
        $userId = $helper->getSession()->getUserId();

        $collection = $this->_filter->getCollection($this->_collectionFactory->create());
        $customerIds = $collection->getAllIds();
        
        $res = $helper->getSyncCustomer($customerIds);

        if ($res && $res[0]) {
            $message = "Customers Successfully Exported In DataExtension!!!";
            $this->_messageManager->addSuccess(__($message));
        } elseif (isset($res[1])) {
            $this->_messageManager->addSuccess(__("Some Customer(s) are not exported"));
        }

        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
        return  $resultRedirect->setPath('customer/index/index', ['store' => $storeId]);
    }
}
