<?php
/**
 * Webkul MarketingCloud Magento Connector SyncAllOrder Controller
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */

namespace Webkul\MarketingCloudMagentoConnector\Controller\Adminhtml\Order;

use Magento\Backend\App\Action;
use Magento\Ui\Component\MassAction\Filter;
use Magento\Framework\Controller\ResultFactory;

class GetAllOrderIds extends \Magento\Backend\App\Action
{
    /**
     * @var \Magento\Backend\Model\View\Result\Forward
     */
    protected $_json;
    protected $_resultForwardFactory;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection,
        \Magento\Sales\Model\Order $orderModel,
        \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\Json\Helper\Data $jsonHelper,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
    ) {


        $this->_orderModel = $orderModel;
        $this->_connection = $connection;
        $this->_resultForwardFactory = $resultForwardFactory;
        $this->_messageManager = $messageManager;
        $this->_scopeConfig = $scopeConfig;
        $this->_json = $jsonHelper;
        parent::__construct($context);

    }

    /**
     * Forward to edit
     *
     * @return \Magento\Backend\Model\View\Result\Forward
     */
    public function execute()
    {
        $helper = $this->_connection;
        $sessionToken = $this->_session->getMarketingToken();
        $token = $this->_scopeConfig->getValue('marketingcloud/general/mc_conn_token');
        $relToken = $helper->genarateToken();
        if (isset($token) && $token != null) {
            $sessionToken = $token;
        }
        if ($sessionToken != $relToken) {
            $resultRedirect = $this->resultRedirectFactory->create();
            $this->messageManager->addError(__("Licence Invalid, Kindly use correct licence key!!!"));
            $this->getResponse()->setHeader('Content-type', 'application/json');
            $this->getResponse()->setBody(0);
        } else {
            $storeId = (int) $this->getRequest()->getParam('store', 0);
            $exportIds = [];
            $helper = $this->_connection;
            $collection = $this->_orderModel->getCollection()
            ->addAttributeToFilter('status', ['neq' => 'canceled'])
            ->addAttributeToSelect('entity_id');

            $exportIds = $collection->getAllIds();
            $this->getResponse()->setHeader('Content-type', 'application/json');
            $this->getResponse()->setBody($this->_json->jsonEncode($exportIds));
        }
    }
}
